// Copyright 2015 Google LLC. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Package preload holds code for adding batches of certificates to CT logs.
package preload

import (
	ct "github.com/google/certificate-transparency-go"
)

// AddedCert holds information about a certificate that has been added to a log.
type AddedCert struct {
	CertDER                    ct.ASN1Cert
	SignedCertificateTimestamp ct.SignedCertificateTimestamp
	AddedOk                    bool
	ErrorMessage               string
}
